@@ -14,6 +14,7 @@
 
 import logging
 
+from ibm_watson_machine_learning.helpers.connections.base_data_connection import BaseDataConnection
 from ibm_watson_machine_learning.messages.messages import Messages
 from ibm_watson_machine_learning.utils import version
 
@@ -83,6 +84,7 @@ class APIClient:
         self.ICP_35 = False # Use it for any 3.5 specific functionalities
         self.ICP_40 = False # Use it for any 4.0 specific functionalities
         self.ICP_45 = False # Use it for any 4.5 specific functionalities
+        self.ICP_46 = False # Use it for any 4.6 specific functionalities
         self.CLOUD_BETA_FLOW = False
         self._iam_id = None
 
@@ -120,7 +122,14 @@ class APIClient:
         import ibm_watson_machine_learning._wrappers.requests as requests
         requests.packages.urllib3.disable_warnings()
 
-        if "token" in wml_credentials:
+        if 'token' not in wml_credentials and 'password' not in wml_credentials and 'apikey' not in wml_credentials:
+            try:
+                self.wml_credentials['token'] = BaseDataConnection._get_token_from_environment()
+                wml_credentials['token'] = self.wml_credentials['token']
+            except Exception as e:
+                pass
+
+        if "token" in self.wml_credentials:
             self.proceed = True
         else:
             self.proceed = False
@@ -129,7 +138,7 @@ class APIClient:
         self.wml_token = None
         self.__wml_local_supported_version_list = ['1.0', '1.1',
                                                    '2.0', '2.0.1', '2.0.2', '2.5.0',
-                                                   '3.0.0', '3.0.1', '3.5', '4.0', '4.5']
+                                                   '3.0.0', '3.0.1', '3.5', '4.0', '4.5', '4.6']
         self.__wsd_supported_version_list = ['1.0', '1.1', '2.0']
         self.__predefined_instance_type_list = ['icp', 'openshift', 'wml_local', 'wsd_local']
         os.environ['WSD_PLATFORM'] = 'False'
@@ -170,13 +179,7 @@ class APIClient:
                 if 'version' not in wml_credentials:
                     raise WMLClientError(Messages.get_message(self.__wml_local_supported_version_list, message_id="version_not_provided"))
 
-                if 'version' in wml_credentials.keys() and (
-                        '2.0.1' == wml_credentials[u'version'].lower() or '2.5.0' == wml_credentials[
-                    u'version'].lower() or
-                        '3.0.0' == wml_credentials[u'version'].lower() or '3.0.1' == wml_credentials[
-                            u'version'].lower() or '3.5' == wml_credentials[u'version'].lower() or
-                        '4.0' == wml_credentials[u'version'].lower() or '4.5' == wml_credentials[u'version'].lower() or
-                        '1.1' == wml_credentials[u'version'].lower() or '2.0' == wml_credentials[u'version'].lower()):
+                if 'version' in wml_credentials.keys() and (wml_credentials[u'version'].lower() in ['2.0.1', '2.5.0', '3.0.0', '3.0.1', '3.5', '4.0', '4.5', '4.6', '1.1', '2.0']):
                     self.CAMS = True
                     os.environ["DEPLOYMENT_PRIVATE"] = "icp4d"
                     if 'wml_local' == wml_credentials[u'instance_id'].lower() and \
@@ -196,10 +199,11 @@ class APIClient:
                         self.ICP_PLATFORM_SPACES = True
                         self.ICP_35 = True
 
-                    if wml_credentials[u'version'].lower() in ['4.0', '4.5']:
+                    if wml_credentials[u'version'].lower() in ['4.0', '4.5', '4.6']:
                         self.ICP_PLATFORM_SPACES = True
                         self.ICP_40 = wml_credentials[u'version'].lower() == '4.0'
                         self.ICP_45 = wml_credentials[u'version'].lower() == '4.5'
+                        self.ICP_46 = wml_credentials[u'version'].lower() == '4.6'
                         if 'bedrock_url' not in wml_credentials:
                             self.wml_credentials['bedrock_url'] = '.'.join(['https://cp-console'] + wml_credentials['url'].split('.')[1:])
                             self._is_bedrock_url_autogenerated = True
