@@ -79,9 +79,9 @@ class ExperimentIterableDataset(IterableDataset):
         **kwargs,
     ):
         super().__init__()
+        self.enable_sampling = enable_sampling
         self._set_sample_size_limit(sample_size_limit)
         self.experiment_metadata = experiment_metadata
-        self.enable_sampling = enable_sampling
         self._wml_client = getattr(connection, "_wml_client", None)
         if self._wml_client is None:
             self._wml_client = kwargs.get("_wml_client", None)
@@ -206,6 +206,9 @@ class ExperimentIterableDataset(IterableDataset):
                 self.sample_size_limit = DEFAULT_SAMPLE_SIZE_LIMIT     # 1GB in bytes
             else:
                 self.sample_size_limit = DEFAULT_REDUCED_SAMPLE_SIZE_LIMIT      # 100MB in bytes
+
+            if self.enable_sampling is False:
+                self.sample_size_limit = None
         else:
             self.sample_size_limit = sample_size_limit
 
@@ -259,6 +262,6 @@ class ExperimentIterableDataset(IterableDataset):
                     return self.connection.read_binary_data(read_to_file=self.read_to_file)
 
                 else:
-                    return self.connection.read()
+                    return self.connection.iterable_read()
         else:
             return (batch for batch in self.connection)
