@@ -180,7 +180,7 @@ class BaseDeployment(ABC):
         # note: This section is only for deployments with specified experiment_id
         if kwargs['experiment_run_id'] is not None:
             run_params = self._source_workspace.wml_client.training.get_details(
-                training_uid=kwargs['experiment_run_id'])
+                training_uid=kwargs['experiment_run_id'], _internal=True)
             wml_pipeline_details = self._source_workspace.wml_client.pipelines.get_details(
                 run_params['entity']['pipeline']['id'])
 
@@ -310,7 +310,7 @@ class BaseDeployment(ABC):
                 else:
                     run_id = optimizer._engine._current_run_id
                     pipeline_id = optimizer._workspace.wml_client.training.get_details(
-                        run_id)['entity']['pipeline']['id']
+                        run_id, _internal=True)['entity']['pipeline']['id']
                     wml_pipeline_details = optimizer._workspace.wml_client.pipelines.get_details(pipeline_id)
 
                 if 'auto_ai.obm' in str(wml_pipeline_details):
@@ -378,7 +378,7 @@ class BaseDeployment(ABC):
                     else:
                         training_result_reference = kwargs['metadata'].get('training_result_reference')
                         run_id = training_result_reference.location.path.split('/')[-3]
-                        run_params = self._source_workspace.wml_client.training.get_details(training_uid=run_id)
+                        run_params = self._source_workspace.wml_client.training.get_details(training_uid=run_id, _internal=True)
 
                         schema, artifact_name = prepare_auto_ai_model_to_publish(
                             pipeline_model=model,
@@ -402,7 +402,7 @@ class BaseDeployment(ABC):
 
                         optimizer_2 = AutoAI(self._source_workspace).runs.get_optimizer(metadata=kwargs['metadata'])
                         run_details = optimizer_2._workspace.wml_client.training.get_details(
-                            optimizer_2.get_params()['run_id']
+                            optimizer_2.get_params()['run_id'], _internal=True
                         )
 
                         artifact_name, model_props = prepare_auto_ai_model_to_publish_notebook_normal_scenario(
@@ -426,7 +426,7 @@ class BaseDeployment(ABC):
                     else:
                         training_result_reference = kwargs['metadata'].get('training_result_reference')
                         run_id = training_result_reference.location.path.split('/')[-3]
-                        run_params = self._source_workspace.wml_client.training.get_details(training_uid=run_id)
+                        run_params = self._source_workspace.wml_client.training.get_details(training_uid=run_id, _internal=True)
 
                         artifact_name, model_props = prepare_auto_ai_model_to_publish_normal_scenario(
                             pipeline_model=model,
