@@ -150,7 +150,8 @@ class WebService(BaseDeployment):
         >>> deployment.create(
         >>>        experiment_run_id="...",
         >>>        model=model,
-        >>>        deployment_name='My new deployment'
+        >>>        deployment_name='My new deployment',
+        >>>        serving_name='my_new_deployment'
         >>>    )
         """
         return super().create(model=model,
