@@ -29,7 +29,7 @@ from ibm_watson_machine_learning.utils.autoai.utils import check_dependencies_ve
     translate_imputation_string_strategy_to_enum, translate_estimator_string_to_enum, \
     translate_batched_estimator_string_to_enum
 from ibm_watson_machine_learning.workspace import WorkSpace
-from ibm_watson_machine_learning.wml_client_error import ForbiddenActionForGitBasedProject
+from ibm_watson_machine_learning.wml_client_error import ForbiddenActionForGitBasedProject, WMLClientError
 from ibm_watson_machine_learning.messages.messages import Messages
 from .engines import WMLEngine
 from .optimizers import LocalAutoPipelines, RemoteAutoPipelines
@@ -91,6 +91,7 @@ class AutoAI(BaseExperiment):
     Transformers = Transformers
     DataConnectionTypes = DataConnectionTypes
     PipelineTypes = PipelineTypes
+    SamplingTypes = SamplingTypes
 
     def __init__(self,
                  wml_credentials: Union[dict, 'WorkSpace'] = None,
@@ -479,7 +480,9 @@ class AutoAI(BaseExperiment):
                 message="Support for excel sheet as number of the sheet (int) is deprecated! Please set excel sheet with name of the sheet.")
 
         if data_join_graph is not None:
-            if self._workspace.wml_client.ICP:
+            if self._workspace.wml_client.ICP_46:
+                raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cpd"))
+            elif self._workspace.wml_client.ICP:
                 print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
             #else:
             #    print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
