@@ -115,35 +115,19 @@ class Experiments(WMLResource):
         else:
             self.ConfigurationMetaNames._validate(meta_props)
 
-
-        if not self._ICP:
-            if self._client.CLOUD_PLATFORM_SPACES:
-                response_experiment_post = requests.post(
-                    self._client.service_instance._href_definitions.get_experiments_href(),
-                    params=self._client._params(skip_for_create=True),
-                    json=metaProps,
-                    headers=self._client._get_headers()
-                )
-            else:
-                response_experiment_post = requests.post(
-                    self._client.service_instance._href_definitions.get_experiments_href(),
-                    json=metaProps,
-                    headers=self._client._get_headers()
-                )
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+            response_experiment_post = requests.post(
+                self._client.service_instance._href_definitions.get_experiments_href(),
+                params=self._client._params(skip_for_create=True),
+                json=metaProps,
+                headers=self._client._get_headers()
+            )
         else:
-            if self._client.ICP_PLATFORM_SPACES:
-                response_experiment_post = requests.post(
-                    self._client.service_instance._href_definitions.get_experiments_href(),
-                    json=metaProps,
-                    params=self._client._params(skip_for_create=True),
-                    headers=self._client._get_headers()
-                )
-            else:
-                response_experiment_post = requests.post(
-                    self._client.service_instance._href_definitions.get_experiments_href(),
-                    json=metaProps,
-                    headers=self._client._get_headers()
-                )
+            response_experiment_post = requests.post(
+                self._client.service_instance._href_definitions.get_experiments_href(),
+                json=metaProps,
+                headers=self._client._get_headers()
+            )
 
         return self._handle_response(201, u'saving experiment', response_experiment_post)
 
