@@ -1031,6 +1031,11 @@ class BaseDataConnection(ABC):
     def _get_token_from_environment():
         if os.environ.get('RUNTIME_ENV_ACCESS_TOKEN_FILE'):
             with open(os.environ.get('RUNTIME_ENV_ACCESS_TOKEN_FILE'), 'r') as f:
-                return f.read()
+                token = f.read()
         else:
-            return os.environ.get('USER_ACCESS_TOKEN')
+            token = os.environ.get('USER_ACCESS_TOKEN')
+
+        if token:
+            token = token.replace('Bearer ', '')
+
+        return token
