@@ -35,6 +35,7 @@ import io
 import os
 import uuid
 import copy
+import sys
 from copy import deepcopy
 from typing import Union, Tuple, List, TYPE_CHECKING, Optional
 from warnings import warn
@@ -445,7 +446,11 @@ class DataConnection(BaseDataConnection):
             return X_train, X_holdout, y_train, y_holdout
 
         else:
-            try_import_autoai_libs(minimum_version='1.12.14')
+            if sys.version_info >= (3, 10):
+                try_import_autoai_libs(minimum_version='1.14.0')
+            else:
+                try_import_autoai_libs(minimum_version='1.12.14')
+
             from autoai_libs.utils.holdout_utils import make_holdout_split, numpy_split_on_target_values
             from autoai_libs.utils.sampling_utils import numpy_sample_rows
 
@@ -605,7 +610,8 @@ class DataConnection(BaseDataConnection):
             use_flight = kwargs.get(
                 'use_flight',
                 bool((self._wml_client is not None or 'USER_ACCESS_TOKEN' in os.environ or 'RUNTIME_ENV_ACCESS_TOKEN_FILE' in os.environ) and (
-                        self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.CLOUD_PLATFORM_SPACES)))
+                        self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.ICP_46 or
+                        self._wml_client.CLOUD_PLATFORM_SPACES)))
         except:
             use_flight = False
 
@@ -883,7 +889,7 @@ class DataConnection(BaseDataConnection):
 
                 if _return_subsampling_stats:
                     X_train, X_holdout, y_train, y_holdout = self._recreate_holdout(data=data[0])
-                    return X_train, X_holdout, y_train, y_holdout, data[1], data[2]
+                    return X_train, X_holdout, y_train, y_holdout, data[1]
                 else:
                     X_train, X_holdout, y_train, y_holdout = self._recreate_holdout(data=data)
                     return X_train, X_holdout, y_train, y_holdout
@@ -903,7 +909,7 @@ class DataConnection(BaseDataConnection):
                     else:
                         test_X, test_y = self._recreate_holdout(data=data[0], with_holdout_split=False)
                         test_X[self.auto_pipeline_params.get('prediction_column', 'prediction_column')] = test_y
-                        return test_X, data[1], data[2]
+                        return test_X, data[1]
 
                 else: # when this data connection is a test / holdout one and no subsampling stats are needed
                     if self.auto_pipeline_params.get('prediction_columns') or \
@@ -933,7 +939,8 @@ class DataConnection(BaseDataConnection):
         use_flight = kwargs.get(
             'use_flight',
             bool((self._wml_client is not None or 'USER_ACCESS_TOKEN' in os.environ or 'RUNTIME_ENV_ACCESS_TOKEN_FILE' in os.environ) and (
-                    self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.CLOUD_PLATFORM_SPACES)))
+                    self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.ICP_46 or
+                    self._wml_client.CLOUD_PLATFORM_SPACES)))
 
         flight_parameters = kwargs.get('flight_parameters', {})
 
