@@ -627,7 +627,16 @@ class FlightConnection:
         self.callback.status_message("Starting reading training data in batches...")
         if self.enable_subsampling:
             for data in self.read():
-                yield data
+                if self.return_subsampling_stats:
+                    data_stats = {"data_size": self.downloaded_data_size,
+                                  "data_batch_size": sys.getsizeof(data),
+                                  "data_batch_no_rows": len(data),
+                                  "no_batches": self.downloaded_data_size // sys.getsizeof(data)}
+                    yield data, data_stats
+                else:
+                    yield data
+                #rerurn stats here
+
             self.enable_subsampling = False
 
         sequences = []
@@ -646,7 +655,12 @@ class FlightConnection:
             logger.debug(f"IR: Logical batch number {n} received.")
             logger.debug(f"IR: Passing batch to upper layer.")
             self._check_for_breaking_exceptions()
-            yield batch
+            if self.return_subsampling_stats:
+                yield batch, {"data_batch_size": sys.getsizeof(batch),
+                              "data_batch_no_rows": len(batch)}
+            else:
+                yield batch
+
             logger.debug(f"IR: We have control back, creating next batch...")
             if n == 0 and self.stop_after_first_batch:
                 self._set_stop_reading(True)
@@ -716,10 +730,7 @@ class FlightConnection:
 
             if self.enable_subsampling:
                 self.subsampled_data = self._process_data(self.subsampled_data)
-                if self.return_subsampling_stats:
-                    yield self.subsampled_data, self.downloaded_data_size, self.downloaded_data_size // self.data_batch_size
-                else:
-                    yield self.subsampled_data
+                yield self.subsampled_data
 
             else:
                 self.data = self._process_data(self.data)
@@ -910,8 +921,9 @@ class FlightConnection:
 
                 # when the last thread finish reading (finish sequence (-1, -1))
                 if isinstance(data, int) and thread_number == -1 and data == -1:
-                    data = pd.concat(logical_batch)  # flush last data
-                    yield self._process_data(data)
+                    if logical_batch:
+                        data = pd.concat(logical_batch)  # flush last data
+                        yield self._process_data(data)
                     break
 
                 # when not the last thread finished reading, continue
@@ -924,9 +936,13 @@ class FlightConnection:
                 logger.debug(f"LB: Mini batch number: {mini_batch_counter}")
 
             except queue.Empty:
-                raise DataStreamError(reason=f'LB: Timeout on waiting for data batch... max {timeout / 60} minutes.')
+                if data is None or data.empty:   # raise the error only if any data were not downloaded.
+                    raise DataStreamError(
+                        reason=f'LB: No data were downloaded in the thread due to timeout on '
+                               f'waiting for data batch: max {timeout / 60} minutes.')
 
             logical_batch.append(data.iloc[:max_rows])
+            not_used_data = data.iloc[max_rows:]
             max_rows = max_rows - len(logical_batch[-1])
 
             if max_rows > 0:
@@ -937,8 +953,7 @@ class FlightConnection:
                 data = pd.concat(logical_batch)  # flush last data
                 yield self._process_data(data)
 
-                rows = len(logical_batch[-1])
-                logical_batch = [data.iloc[rows + 1:]]
+                logical_batch = [not_used_data]
                 max_rows = self._get_max_rows(_type=_type) - len(logical_batch[-1])
 
     def _select_source_command(self, infer_schema: bool = True) -> List[str]:
