@@ -375,7 +375,7 @@ class ServiceInstanceNewPlan:
             **returns**: Newly created token if returned if no errors occurred.\n
             **return type**: str\n
         """
-        if (self._client.ICP_40 or self._client.ICP_45) and 'bedrock_url' in self._client.wml_credentials and 'password' in self._client.wml_credentials:
+        if (self._client.ICP_40 or self._client.ICP_45 or self._client.ICP_46) and 'bedrock_url' in self._client.wml_credentials and 'password' in self._client.wml_credentials:
             try:
                 return self._get_cpd_token_from_request_new_auth_flow()
             except Exception as e1:
