@@ -14,7 +14,8 @@
 
 from __future__ import print_function
 
-import os.path
+import json
+from os import path, devnull
 from ibm_watson_machine_learning.libs.repo.mlrepository.meta_names import MetaNames
 from ibm_watson_machine_learning.libs.repo.base_constants import *
 from ibm_watson_machine_learning.libs.repo.util.library_imports import LibraryChecker
@@ -28,6 +29,7 @@ from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.generic_archive_
 from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.function_artifact import FunctionArtifact
 from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.hybrid_pipeline_model_artifact import HybridPipelineModelArtifact
 
+
 def MLRepositoryArtifact(ml_artifact= None,
                          training_data=None,
                          training_dataref=None,
@@ -98,7 +100,7 @@ def MLRepositoryArtifact(ml_artifact= None,
                         raise TypeError('The artifact specified ( {} ) is not of type "tar.gz" or "tgz" or "zip". Only compressed archive of '
                                     '"tar.gz" or "tgz" format is supported.'.format(ml_artifact))
 
-                    if not os.path.exists(ml_artifact):
+                    if not path.exists(ml_artifact):
                         raise IOError('The artifact specified ( {} ) does not exist.'.format(ml_artifact))
                     return _get_libraries_artifact(ml_artifact, name, meta_props)
 
@@ -165,9 +167,8 @@ def MLRepositoryArtifact(ml_artifact= None,
                                               meta_props=meta_props)
         if lib_checker.installed_libs[XGBOOST]:
             import sys
-            import os
             try:
-                sys.stderr = open(os.devnull, 'w')
+                sys.stderr = open(devnull, 'w')
                 import xgboost as xgb
             except Exception as ex:
                 print('Failed to import xgboost. Error: ' + str(ex))
@@ -248,7 +249,7 @@ def MLRepositoryArtifact(ml_artifact= None,
                 raise TypeError('The artifact specified ( {} ) is not of type "tar.gz" or "tgz". Only compressed archive of '
                              '"tar.gz" or "tgz" format is supported.'.format(ml_artifact))
 
-         if not os.path.exists(ml_artifact):
+         if not path.exists(ml_artifact):
             raise IOError('The artifact specified ( {} ) does not exist.'.format(ml_artifact))
 
          if MetaNames.TYPE not in meta_props.get():
