@@ -121,6 +121,15 @@ class ScikitPipelineModelArtifact(ModelArtifact):
                     raise ValueError("Training target column has not been provided for the training data set")
                 self.meta.merge(self._get_schema(training_features, training_target, feature_names, label_column_names))
 
+            if self.meta.prop(MetaNames.INPUT_DATA_SCHEMA) is None:
+                try:
+                    input_data_schema = {'fields': [f for f in self.meta.prop(MetaNames.TRAINING_DATA_SCHEMA)['fields'] if
+                                                    f['name'] != self.meta.prop(MetaNames.LABEL_FIELD)], 'type': 'struct',
+                                         'id': '1'}
+                    self.meta.add(MetaNames.INPUT_DATA_SCHEMA, input_data_schema)
+                except:
+                    pass
+
             self._reader = ScikitPipelineReader(self.ml_pipeline_model)
 
 
