@@ -15,7 +15,8 @@
 from ibm_watson_machine_learning.libs.repo.swagger_client.apis.repository_api import RepositoryApi
 from ibm_watson_machine_learning.libs.repo.swagger_client.rest import ApiException
 
-import requests, certifi, os
+import ibm_watson_machine_learning._wrappers.requests as requests
+import certifi, os
 
 try:
     import urllib3
@@ -51,8 +52,7 @@ class MLRepositoryApi(RepositoryApi):
                 version_id
             ),
                 headers=self.api_client.default_headers,
-                data=content_stream,
-                verify=False
+                data=content_stream
             )
             if r.status_code != 200:
                 raise ApiException(r.status_code, r.text)
@@ -83,8 +83,7 @@ class MLRepositoryApi(RepositoryApi):
             ),
                 headers=self.api_client.default_headers,
                 data=content_stream,
-                params=query_parameters,
-                verify=False
+                params=query_parameters
             )
             if (r.status_code != 200 and r.status_code !=202):
                 raise ApiException(r.status_code, r.text)
@@ -100,16 +99,12 @@ class MLRepositoryApi(RepositoryApi):
             )
 
             if (r.status_code != 200 and r.status_code !=202):
-                verify=True
-                if 'DEPLOYMENT_PLATFORM' in os.environ and os.environ['DEPLOYMENT_PLATFORM'] == 'private':
-                    verify=False
                 r = requests.delete('{}/ml/v4/models/{}'.format(
                     self.api_client.repository_path,
                     model_id
                 ),
                     headers=self.api_client.default_headers,
-                    params=query_parameters,
-                    verify=verify
+                    params=query_parameters
                 )
                 raise ApiException(r.status_code, r.text)
 
@@ -120,11 +115,6 @@ class MLRepositoryApi(RepositoryApi):
         else:
             query_parameters = {}
 
-        if 'DEPLOYMENT_PLATFORM' in os.environ and os.environ['DEPLOYMENT_PLATFORM'] == 'private':
-            verify = False
-        else:
-            verify = True
-
         r = requests.put('{}/ml/v4/models/{}/content'.format(
             self.api_client.repository_path,
             model_id
@@ -132,21 +122,16 @@ class MLRepositoryApi(RepositoryApi):
         ),
             headers=self.api_client.default_headers,
             data=content_stream,
-            params=query_parameters,
-            verify=verify
+            params=query_parameters
         )
         if (r.status_code != 201 and r.status_code !=202):
-            # verify=True
-            # #if 'DEPLOYMENT_PLATFORM' in os.environ and os.environ['DEPLOYMENT_PLATFORM'] == 'private':
-            # #    verify=False
             if no_delete is False or no_delete is None:
                 r = requests.delete('{}/ml/v4/models/{}'.format(
                     self.api_client.repository_path,
                     model_id
                 ),
                     headers=self.api_client.default_headers,
-                    params=query_parameters,
-                    verify=verify
+                    params=query_parameters
                 )
             raise ApiException(r.status_code, r.text)
 
@@ -235,8 +220,7 @@ class MLRepositoryApi(RepositoryApi):
                 revision_id
             ),
                 headers=self.api_client.default_headers,
-                data=content_stream,
-                verify=False
+                data=content_stream
             )
             if r.status_code != 200:
                 raise ApiException(r.status_code, r.text)
@@ -259,8 +243,7 @@ class MLRepositoryApi(RepositoryApi):
                 self.api_client.repository_path,
                 library_id),
                 headers=self.api_client.default_headers,
-                data=content_stream,
-                verify=False
+                data=content_stream
             )
             if r.status_code != 200 and r.status_code !=202:
                 raise ApiException(r.status_code, r.text)
@@ -285,8 +268,7 @@ class MLRepositoryApi(RepositoryApi):
                 runtimespec_id
             ),
                 headers=tmp_headers,
-                data=content_stream,
-                verify=False
+                data=content_stream
             )
             if r.status_code != 200 and r.status_code !=202:
                 raise ApiException(r.status_code, r.text)
