@@ -363,7 +363,7 @@ class DataJoinGraph(Digraph, BaseOBMJson):
                 "stage_flag": True,
                 "output_logs": True,
                 "engine": {
-                    "template_id": "spark-3.0.0-automl-template",
+                    "template_id": "spark-3.2-automl-template",
                 },
                 "obm": {
                     "Entity_Graph": {
