@@ -24,6 +24,10 @@ from ibm_watson_machine_learning.wml_resource import WMLResource
 _DEFAULT_LIST_LENGTH = 50
 
 class RemoteTrainingSystem(WMLResource):
+    """ 
+    The RemoteTrainingSystem class represents a Federated Learning party and provides a list of identities
+    that are permitted to join training as the RemoteTrainingSystem.
+    """
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
 
@@ -33,7 +37,7 @@ class RemoteTrainingSystem(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props):
         """
-            Create a remote training system. Either space_id or project_id has to be provided and is mandatory.
+            Create a remote training system. Either space_id or project_id has to be provided.
 
            **Parameters**
 
@@ -54,7 +58,7 @@ class RemoteTrainingSystem(WMLResource):
                 >>>    client.remote_training_systems.ConfigurationMetaNames.TAGS: ["tag1", "tag2"],
                 >>>    client.remote_training_systems.ConfigurationMetaNames.ORGANIZATION: {"name": "name", "region": "EU"}
                 >>>    client.remote_training_systems.ConfigurationMetaNames.ALLOWED_IDENTITIES: [{"id": "43689024", "type": "user"}],
-                >>>    client.remote_training_systems.ConfigurationMetaNames.REMOTE_ADMIN: {"name": "name", "email": "email@email.com"}
+                >>>    client.remote_training_systems.ConfigurationMetaNames.REMOTE_ADMIN: {"id": "43689020", "type": "user"}
                 >>> }
                 >>> client.set.default_space('3fc54cf1-252f-424b-b52d-5cdd9814987f')
                 >>> details = client.remote_training_systems.store(meta_props=metadata)
@@ -150,8 +154,8 @@ class RemoteTrainingSystem(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, remote_training_system_id=None, limit=None, asynchronous=False, get_all=False):
         """
-            Get metadata of the given remote training system. if no remote_training_systems_id is specified all
-            remote training systems metadata is returned.
+            Get metadata of the given Remote Training System. If remote_training_system_id is not specified,
+            metadata is returned for all Remote Training Systems.
 
            **Parameters**
 
@@ -172,8 +176,6 @@ class RemoteTrainingSystem(WMLResource):
                 **return type**: dict\n
                 dict (if remote_training_systems_id is not None) or {"resources": [dict]} (if remote_training_systems_id is None)\n
 
-           .. note::
-                If remote_training_systems_id is not specified, all remote training system(s) metadata is fetched\n
 
            **Example**
 
@@ -203,7 +205,7 @@ class RemoteTrainingSystem(WMLResource):
 
     def list(self, limit=None):
         """
-            List stored remote training systems. If limit is set to None there will be only first 50 records shown.
+            List stored remote training systems. If limit is set to None, only the first 50 records are shown.
 
            **Parameters**
 
@@ -332,7 +334,7 @@ class RemoteTrainingSystem(WMLResource):
 
     def get_revision_details(self, remote_training_system_id, rev_id):
         """
-           Get metadata of specific revision of stored remote system
+           Get metadata from the specific revision of a stored remote system
 
            :param remote_training_system_id: stored functions, definition
            :type remote_training_system_id: {str_type}
@@ -370,7 +372,7 @@ class RemoteTrainingSystem(WMLResource):
            :param limit: limit number of fetched records (optional)
            :type limit: int
 
-           :returns: list all remote systems revisions summary.
+           :returns: Summary list of all remote systems revisions
            :rtype: table
 
            >>> details = client.remote_training_systems.list_revisions(remote_training_system_id)
@@ -406,7 +408,7 @@ class RemoteTrainingSystem(WMLResource):
 
     def create_party(self, remote_training_system_id, party_metadata):
         """
-        Create a party object using the specified remote training system id and the party metadata.
+        Creates a party object using the specified remote training system id and the party metadata.
 
         **Parameters**
 
@@ -423,7 +425,7 @@ class RemoteTrainingSystem(WMLResource):
             **returns**: A party object with the specified rts_id and configuration\n
             **return type**: Party\n
 
-        **Example**
+        **Examples**
          >>> party_metadata = {
          >>>     wml_client.remote_training_systems.ConfigurationMetaNames.DATA_HANDLER: {
          >>>        "info": {
@@ -441,6 +443,16 @@ class RemoteTrainingSystem(WMLResource):
          >>>     },
          >>> }
          >>> party = client.remote_training_systems.create_party(remote_training_system_id, party_metadata)
+         >>> 
+         >>> party_metadata = {
+         >>>     wml_client.remote_training_systems.ConfigurationMetaNames.DATA_HANDLER: {
+         >>>        "info": {
+         >>>            "npz_file": "./data_party0.npz"
+         >>>        },
+         >>>        "class": MnistTFDataHandler
+         >>>     }
+         >>> }
+         >>> party = client.remote_training_systems.create_party(remote_training_system_id, party_metadata)
 
         """
 
