@@ -172,12 +172,9 @@ class Runtimes(WMLResource):
                     "It is mandatory is set the space. Use client.set.default_space(<SPACE_GUID>) to set the space.")
 
         try:
-            if not self._ICP:
-                response_post = requests.post(self._client.service_instance._href_definitions.get_custom_libraries_href(), json=lib_metadata,
-                                              headers=self._client._get_headers())
-            else:
-                response_post = requests.post(self._client.service_instance._href_definitions.get_custom_libraries_href(), json=lib_metadata,
-                                              headers=self._client._get_headers())
+            response_post = requests.post(self._client.service_instance._href_definitions.get_custom_libraries_href(), json=lib_metadata,
+                                          headers=self._client._get_headers())
+
             details = self._handle_response(201, u'saving libraries', response_post)
 
             if self.LibraryMetaNames.FILEPATH in meta_props:
@@ -234,12 +231,9 @@ class Runtimes(WMLResource):
             metadata[MetaNames.CONTENT_LOCATION] = meta_props[self.ConfigurationMetaNames.CONFIGURATION_FILEPATH]
 
         try:
-            if not self._ICP:
-                response_post = requests.post(self._client.service_instance._href_definitions.get_runtimes_href(), json=metadata,
-                                              headers=self._client._get_headers())
-            else:
-                response_post = requests.post(self._client.service_instance._href_definitions.get_runtimes_href(), json=metadata,
-                                              headers=self._client._get_headers())
+            response_post = requests.post(self._client.service_instance._href_definitions.get_runtimes_href(), json=metadata,
+                                          headers=self._client._get_headers())
+
             details = self._handle_response(201, u'saving runtimes', response_post)
             if self.ConfigurationMetaNames.CONFIGURATION_FILEPATH in meta_props:
                 try:
@@ -649,10 +643,7 @@ class Runtimes(WMLResource):
             if len(self._get_runtimes_uids_for_lib(lib_uid, details)) == 0:
                 print('Deleting orphaned \'{}\' library... '.format(lib_uid), end="")
                 library_endpoint = self._client.service_instance._href_definitions.get_custom_library_href(lib_uid)
-                if not self._ICP:
-                    response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
-                else:
-                    response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
+                response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
 
                 try:
                     self._handle_response(204, u'library deletion', response_delete, False)
@@ -688,10 +679,8 @@ class Runtimes(WMLResource):
 
         Runtimes._validate_type(library_uid, u'library_uid', STR_TYPE, True)
         library_endpoint = self._client.service_instance._href_definitions.get_custom_library_href(library_uid)
-        if not self._ICP:
-            response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
-        else:
-            response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
+
+        response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
 
         return self._handle_response(204, u'library deletion', response_delete, False)
 
@@ -974,10 +963,9 @@ class Runtimes(WMLResource):
         patch_payload = self.LibraryMetaNames._generate_patch_payload(details['entity'], changes, with_validation=True)
 
         url = self._client.service_instance._href_definitions.get_custom_library_href(library_uid)
-        if not self._ICP:
-            response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
-        else:
-            response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
+
+        response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
+
         updated_details = self._handle_response(200, u'library patch', response)
 
         return updated_details
@@ -1022,10 +1010,9 @@ class Runtimes(WMLResource):
         patch_payload = self.LibraryMetaNames._generate_patch_payload(details['entity'], changes, with_validation=True)
 
         url = self._client.service_instance._href_definitions.get_runtime_href(runtime_uid)
-        if not self._ICP:
-            response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
-        else:
-            response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
+
+        response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
+
         updated_details = self._handle_response(200, u'library patch', response)
 
         return updated_details
@@ -1088,12 +1075,9 @@ class Runtimes(WMLResource):
             clone_meta["rev"] = rev
 
         url = self._client.service_instance._href_definitions.get_runtime_href(runtime_uid)
-        if not self._ICP:
-            response_post = requests.post(url, json=clone_meta,
-                                              headers=self._client._get_headers())
-        else:
-            response_post = requests.post(url, json=clone_meta,
-                                              headers=self._client._get_headers())
+
+        response_post = requests.post(url, json=clone_meta,
+                                          headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=200, operationName=u'cloning runtime',
                                             response=response_post)
@@ -1157,12 +1141,9 @@ class Runtimes(WMLResource):
             clone_meta["rev"] = rev
 
         url = self._client.service_instance._href_definitions.get_custom_library_href(library_uid)
-        if not self._ICP:
-            response_post = requests.post(url, json=clone_meta,
-                                              headers=self._client._get_headers())
-        else:
-            response_post = requests.post(url, json=clone_meta,
-                                              headers=self._client._get_headers())
+
+        response_post = requests.post(url, json=clone_meta,
+                                          headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=200, operationName=u'cloning library',
                                             response=response_post)
