@@ -180,10 +180,8 @@ class Spaces(WMLResource):
         Spaces._validate_type(space_uid, u'space_uid', STR_TYPE, True)
 
         space_endpoint = self._client.service_instance._href_definitions.get_space_href(space_uid)
-        if not self._ICP:
-            response_delete = requests.delete(space_endpoint, headers=self._client._get_headers())
-        else:
-            response_delete = requests.delete(space_endpoint, headers=self._client._get_headers())
+
+        response_delete = requests.delete(space_endpoint, headers=self._client._get_headers())
 
         return self._handle_response(204, u'space deletion', response_delete, False)
 
@@ -289,10 +287,9 @@ class Spaces(WMLResource):
                                                                             with_validation=True)
 
         href = self._client.service_instance._href_definitions.get_space_href(space_uid)
-        if not self._ICP:
-            response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
-        else:
-            response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
+
+        response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
+
         updated_details = self._handle_response(200, u'spaces patch', response)
 
         return updated_details
@@ -374,10 +371,8 @@ class Spaces(WMLResource):
         Spaces._validate_type(member_id, u'member_id', STR_TYPE, True)
 
         member_endpoint = self._client.service_instance._href_definitions.get_member_href(space_uid,member_id)
-        if not self._ICP:
-            response_delete = requests.delete(member_endpoint, headers=self._client._get_headers())
-        else:
-            response_delete = requests.delete(member_endpoint, headers=self._client._get_headers())
+
+        response_delete = requests.delete(member_endpoint, headers=self._client._get_headers())
 
         return self._handle_response(204, u'space member deletion', response_delete, False)
 
@@ -425,11 +420,10 @@ class Spaces(WMLResource):
             patch_payload = self.MemberMetaNames._generate_patch_payload(details['entity'], changes,
                                                                                 with_validation=True)
 
-            href = self._client.service_instance._href_definitions.get_member_href(space_uid,member_id)
-            if not self._ICP:
-                response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
-            else:
-                response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
+            href = self._client.service_instance._href_definitions.get_member_href(space_uid, member_id)
+
+            response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
+
             updated_details = self._handle_response(200, u'members patch', response)
 
             return updated_details
@@ -615,11 +609,8 @@ class Spaces(WMLResource):
 
         href = self._client.service_instance._href_definitions.get_space_href(space_uid) + "/imports"
 
+        response = requests.post(href, headers=self._client._get_headers(), data=data)
 
-        if not self._ICP:
-            response = requests.post(href, headers=self._client._get_headers(), data=data)
-        else:
-            response = requests.post(href, headers=self._client._get_headers(), data=data)
         import_space_details = self._handle_response(202, u'spaces import', response)
 
         return import_space_details
@@ -723,10 +714,8 @@ class Spaces(WMLResource):
         else:
             href =  self._client.service_instance._href_definitions.get_space_href(space_uid) + "/imports/" + imports_id
 
-        if not self._ICP:
-            response = requests.get(href, headers=self._client._get_headers())
-        else:
-            response = requests.get(href, headers=self._client._get_headers())
+        response = requests.get(href, headers=self._client._get_headers())
+
         import_space_details = self._handle_response(200, u'spaces import details', response)
 
         return import_space_details
@@ -774,10 +763,8 @@ class Spaces(WMLResource):
 
         href = self._client.service_instance._href_definitions.get_space_href(space_uid) + "/exports"
 
-        if not self._ICP:
-            response = requests.post(href, headers=self._client._get_headers(), data=space_exports_meta_json)
-        else:
-            response = requests.post(href, headers=self._client._get_headers(), data=space_exports_meta_json)
+        response = requests.post(href, headers=self._client._get_headers(), data=space_exports_meta_json)
+
         export_space_details = self._handle_response(202, u'spaces export', response)
 
         return export_space_details
@@ -823,10 +810,8 @@ class Spaces(WMLResource):
         else:
             href =  self._client.service_instance._href_definitions.get_space_href(space_uid) + "/exports/" + exports_id
 
-        if not self._ICP:
-            response = requests.get(href, headers=self._client._get_headers())
-        else:
-            response = requests.get(href, headers=self._client._get_headers())
+        response = requests.get(href, headers=self._client._get_headers())
+
         export_space_details = self._handle_response(200, u'spaces exports details', response)
 
         return export_space_details
