@@ -80,7 +80,6 @@ class BatchedClassificationAlgorithms(Enum):
     EX_TREES = "BatchedTreeEnsembleClassifier(ExtraTreesClassifier)"
     LGBM = "BatchedTreeEnsembleClassifier(LGBMClassifier)"
     XGB = "BatchedTreeEnsembleClassifier(XGBClassifier)"
-    GB = "BatchedTreeEnsembleClassifier(GradientBoostingClassifier)"
     SnapRF = "BatchedTreeEnsembleClassifier(SnapRandomForestClassifier)"
     SnapBM = "BatchedTreeEnsembleClassifier(SnapBoostingMachineClassifier)"
 
@@ -124,7 +123,6 @@ class BatchedRegressionAlgorithms(Enum):
     RF = "BatchedTreeEnsembleRegressor(RandomForestRegressor)"
     EX_TREES = "BatchedTreeEnsembleRegressor(ExtraTreesRegressor)"
     LGBM = "BatchedTreeEnsembleRegressor(LGBMRegressor)"
-    GB = "BatchedTreeEnsembleRegressor(GradientBoostingRegressor)"
     SnapRF = "BatchedTreeEnsembleRegressor(SnapRandomForestRegressor)"
     SnapBM = "BatchedTreeEnsembleRegressor(SnapBoostingMachineRegressor)"
     XGB = "BatchedTreeEnsembleRegressor(XGBRegressor)"
@@ -179,22 +177,22 @@ class ForecastingPipelineTypes(Enum):
     @staticmethod
     def get_exogenous():
         """
-        Get list of exogenous pipelines.
+        Get list of pipelines that use supporting features (exogenous pipelines).
 
         Returns
         -------
-        List of exogenous pipelines.
+        List of pipelines using supporting features.
         """
         return [pipeline for pipeline in ForecastingPipelineTypes if pipeline.value.startswith('Exogenous')]
 
     @staticmethod
     def get_non_exogenous():
         """
-        Get list of non-exogenous pipelines.
+        Get list of pipelines not using supporting features (non-exogenous pipelines).
 
         Returns
         -------
-        List of non-exogenous pipelines.
+        List of pipelines that do not use supporting features.
         """
         return [pipeline for pipeline in ForecastingPipelineTypes if not pipeline.value.startswith('Exogenous')]
 
