@@ -30,7 +30,12 @@ __all__ = [
     "CannotAutogenerateBedrockUrl",
     "WrongMetaProps",
     "CannotSetProjectOrSpace",
-    "ForbiddenActionForGitBasedProject"
+    "ForbiddenActionForGitBasedProject",
+    "CannotInstallLibrary",
+    "DataStreamError",
+    "WrongLocationProperty",
+    "WrongFileLocation",
+    "SpaceIDandProjectIDCannotBeNone"
 ]
 
 
@@ -156,3 +161,28 @@ class ForbiddenActionForGitBasedProject(WMLClientError):
     def __init__(self, reason):
         WMLClientError.__init__(self, f"This action is not supported for git based project.",
                                 reason=reason)
+
+
+class CannotInstallLibrary(WMLClientError, ValueError):
+    def __init__(self, lib_name: str, reason: str):
+        WMLClientError.__init__(self, f"Library '{lib_name}' cannot be installed! Please install it manually.", reason)
+
+
+class DataStreamError(WMLClientError, ConnectionError):
+    def __init__(self, reason):
+        WMLClientError.__init__(self, "Cannot fetch data via Flight Service. Try again.", reason)
+
+
+class WrongLocationProperty(WMLClientError, ConnectionError):
+    def __init__(self, reason):
+        WMLClientError.__init__(self, "Cannot fetch data via Flight Service. Try again.", reason)
+
+
+class WrongFileLocation(WMLClientError, ValueError):
+    def __init__(self, reason):
+        WMLClientError.__init__(self, "Cannot fetch data via Flight Service. Try again.", reason)
+
+
+class SpaceIDandProjectIDCannotBeNone(WMLClientError, ValueError):
+    def __init__(self, reason: str):
+        WMLClientError.__init__(self, f"Missing 'space_id' or 'project_id'.", reason)
